--AH:ScriptId=cdc8cca8-3632-4c3a-97ee-4875b718933d;3074
CREATE TABLE [DockerImages]
(
	[Feed_Id] INT NOT NULL,
	[Repository_Name] VARCHAR(255) NOT NULL,
	[Image_Digest] VARCHAR(128) NOT NULL,
	[ManifestJson_Bytes] VARBINARY(MAX) NOT NULL,
	[Download_Count] INT NOT NULL,
	[Published_Date] DATETIME NOT NULL

	CONSTRAINT [FK__DockerImages__Feeds]
		FOREIGN KEY ([Feed_Id])
		REFERENCES [Feeds] ([Feed_Id])
		ON DELETE CASCADE,

	CONSTRAINT [PK__DockerImages]
		PRIMARY KEY NONCLUSTERED ([Feed_Id], [Repository_Name], [Image_Digest])
)

CREATE CLUSTERED INDEX [IX__DockerImages__Clustered]
	ON [DockerImages] ([Feed_Id], [Repository_Name], [Published_Date])

CREATE TABLE [DockerRepositoryDescriptions]
(
	[Feed_Id] INT NOT NULL,
	[Repository_Name] VARCHAR(255) NOT NULL,
	[ShortDescription_Text] NVARCHAR(100) NULL,
	[FullDescription_Text] NVARCHAR(MAX) NULL,

	CONSTRAINT [FK__DockerRepositoryDescriptions__Feeds]
		FOREIGN KEY ([Feed_Id])
		REFERENCES [Feeds] ([Feed_Id])
		ON DELETE CASCADE,

	CONSTRAINT [PK__DockerRepositoryDescriptions]
		PRIMARY KEY ([Feed_Id], [Repository_Name])
)

CREATE TABLE [DockerImageTags]
(
	[Feed_Id] INT NOT NULL,
	[Repository_Name] VARCHAR(255) NOT NULL,
	[Tag_Name] VARCHAR(128) NOT NULL,
	[Image_Digest] VARCHAR(128) NOT NULL,

	CONSTRAINT [FK__DockerImageTags__DockerImages]
		FOREIGN KEY ([Feed_Id], [Repository_Name], [Image_Digest])
		REFERENCES [DockerImages] ([Feed_Id], [Repository_Name], [Image_Digest])
		ON DELETE CASCADE,

	CONSTRAINT [PK__DockerImageTags]
		PRIMARY KEY ([Feed_Id], [Repository_Name], [Tag_Name])
)

CREATE TABLE [DockerBlobs]
(
	[Feed_Id] INT NOT NULL,
	[Blob_Digest] VARCHAR(128) NOT NULL,
	[Download_Count] INT NOT NULL,
	[LastRequested_Date] DATETIME NULL,
	[Blob_Size] BIGINT NOT NULL,

	CONSTRAINT [PK__DockerBlobs]
		PRIMARY KEY ([Feed_Id], [Blob_Digest]),

	CONSTRAINT [FK__DockerBlobs__Feeds]
		FOREIGN KEY ([Feed_Id])
		REFERENCES [Feeds] ([Feed_Id])
		ON DELETE CASCADE
)

CREATE TABLE [DockerBlobUploads]
(
	[Feed_Id] INT NOT NULL,
	[Upload_Id] VARCHAR(50) NOT NULL,
	[BytesReceived_Count] BIGINT NOT NULL,
	[LatestChunkReceived_Date] DATETIME NOT NULL,

	CONSTRAINT [PK__DockerBlobUploads]
		PRIMARY KEY ([Feed_Id], [Upload_Id]),

	CONSTRAINT [FK__DockerBlobUploads__Feeds]
		FOREIGN KEY ([Feed_Id])
		REFERENCES [Feeds] ([Feed_Id])
		ON DELETE CASCADE,

	CONSTRAINT [CK__DockerBlobUploads__Upload_Id]
		CHECK ([Upload_Id] <> ''),

	CONSTRAINT [CK__DockerBlobUploads__BytesReceived_Count]
		CHECK ([BytesReceived_Count] >= 0)
)
