IF OBJECT_ID('[Packages_Combined]') IS NOT NULL DROP VIEW [Packages_Combined]
GO

CREATE VIEW [Packages_Combined]
AS
	SELECT * FROM
	(SELECT P.[Feed_Id],
	        F.[Feed_Name],
			P.[Package_Id],
			V.[Version_Text],
			V.[Published_Date],
			F.[FeedType_Name],
            V.[Download_Count],
            [Group_Id] = NULL
	  FROM [NuGetPackageVersionsV2] V
	       INNER JOIN [NuGetPackagesV2] P
		           ON P.[NuGetPackageV2_Id] = V.[NuGetPackageV2_Id]
	       INNER JOIN [Feeds] F
		           ON F.[Feed_Id] = P.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND V.[Cached_Indicator] = 'N') A

	UNION ALL
	SELECT * FROM
	(SELECT P.[Feed_Id],
	        F.[Feed_Name],
			P.[Package_Id],
			P.[Version_Text],
			P.[Published_Date],
			F.[FeedType_Name],
            P.[Download_Count],
            [Group_Id] = NULL
	  FROM [NuGetPackages] P
	       INNER JOIN [Feeds] F
		           ON F.[Feed_Id] = P.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND P.[Cached_Indicator] = 'N') A

	UNION ALL
	SELECT * FROM

	(SELECT NP.[Feed_Id],
	        F.[Feed_Name],
			[Package_Id] = CASE WHEN NP.[Scope_Name] = '' THEN NP.[Package_Name] ELSE '@' + NP.[Scope_Name] + '/' + NP.[Package_Name] END,
			NPV.[Version_Text],
			NPV.[Published_Date],
			F.[FeedType_Name],
            NPV.[Download_Count],
            [Group_Id] = NULL
		  FROM [NpmPackageVersions] NPV
		       INNER JOIN [NpmPackages] NP
			           ON NP.[Package_Id] = NPV.[Package_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = NP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND NPV.[Cached_Indicator] = 'N') B


	UNION ALL
	SELECT * FROM

	(SELECT MA.[Feed_Id],
	        F.[Feed_Name],
			[Package_Id] = MA.[ArtifactId_Text],
			MAF.[Version_Text],
			MAF.[Updated_Date],
			F.[FeedType_Name],
            MAF.[Download_Count],
            [Group_Id] = MA.[GroupId_Text]
		  FROM [MavenArtifacts] MA
		       INNER JOIN [MavenArtifactFiles] MAF
			           ON MAF.[MavenArtifact_Id] = MA.[MavenArtifact_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = MA.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND MAF.[File_Type] = '.pom'
	   AND MAF.[Cached_Indicator] = 'N') C

	UNION ALL
	SELECT * FROM

	(SELECT F.[Feed_Id],
	        F.[Feed_Name],
			[Package_Id] = PGP.[Package_Name],
			PGPV.[Version_Text],
			PGPV.[Published_Date],
			F.[FeedType_Name],
            PGP.[Download_Count],
            [Group_Id] = PGP.[Group_Name]
		  FROM [ProGetPackageVersions] PGPV
		       INNER JOIN [ProGetPackages] PGP
			           ON PGP.[ProGetPackage_Id] = PGPV.[ProGetPackage_Id]
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = PGP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND PGPV.[Cached_Indicator] = 'N') D

	UNION ALL
	SELECT * FROM

	(SELECT F.[Feed_Id],
	        F.[Feed_Name],
			[Package_Id] = DP.[Package_Name] + '/' + DP.[Architecture_Name],
			DP.[Version_Text],
			DP.[Published_Date],
			F.[FeedType_Name],
            DP.[Download_Count],
            [Group_Id] = DP.[Component_Name]
		  FROM [DebianPackages] DP
			   INNER JOIN [Feeds] F
			           ON F.[Feed_Id] = DP.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND DP.[Cached_Indicator] = 'N') E

	UNION ALL
	SELECT * FROM

	(SELECT F.[Feed_Id],
	        F.[Feed_Name],
	        [Package_Id] = HC.[Chart_Name],
	        HC.[Version_Text],
	        HC.[Published_Date],
	        F.[FeedType_Name],
	        HC.[Download_Count],
	        [Group_Id] = NULL
	      FROM [HelmCharts] HC
	           INNER JOIN [Feeds] F
	                   ON F.[Feed_Id] = HC.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND HC.[Cached_Indicator] = 'N') F


	    UNION ALL
	SELECT * FROM

	(SELECT F.[Feed_Id],
	        F.[Feed_Name],
	        [Package_Id] = Py.Package_Name,
	        Py.[Version_Text],
	        Py.[Published_Date],
	        F.[FeedType_Name],
	        Py.[Download_Count],
	        [Group_Id] = NULL
	      FROM PypiPackages Py
	           INNER JOIN [Feeds] F
	                   ON F.[Feed_Id] = Py.[Feed_Id]
	 WHERE F.[Active_Indicator] = 'Y'
	   AND Py.[Cached_Indicator] = 'N') G
GO