EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Feeds_SetFeedProperty',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Sets one or more properties on a feed of any type.'
GO

IF OBJECT_ID('[Feeds_SetFeedProperty]') IS NOT NULL DROP PROCEDURE [Feeds_SetFeedProperty]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Feeds_SetFeedProperty]
(
	@Feed_Id INT,
	@Feed_Name NVARCHAR(50) = NULL,
	@Feed_Description NVARCHAR(MAX) = NULL,
	@Active_Indicator YNINDICATOR = NULL,
	@Cache_Connectors_Indicator YNINDICATOR = NULL,
	@FeedType_Name VARCHAR(20) = NULL,
	@DropPath_Text NVARCHAR(260) = NULL,
	@FeedPathOverride_Text NVARCHAR(260) = NULL,
	@PackageStoreConfiguration_Xml NVARCHAR(MAX) = NULL,
	@AllowUnknownLicenses_Indicator2 VARCHAR(1) = NULL,
	@FeedConfiguration_Xml NVARCHAR(MAX) = NULL,
	@ReplicationConfiguration_Xml NVARCHAR(MAX) = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Current_FeedType_Name VARCHAR(20)
	SET @Current_FeedType_Name = (SELECT [FeedType_Name]
	                                FROM [Feeds]
								   WHERE [Feed_Id] = @Feed_Id)

	IF @Current_FeedType_Name IS NULL
		RAISERROR('Invalid feed ID.', 16, 1)

	IF @FeedType_Name IS NOT NULL AND @Current_FeedType_Name <> @FeedType_Name
	BEGIN

		IF @FeedType_Name NOT IN ('NuGet', 'Chocolatey', 'Deployment', 'PowerShell') OR @Current_FeedType_Name NOT IN ('NuGet', 'Chocolatey', 'Deployment', 'PowerShell')
			RAISERROR('Cannot change feed type.', 16, 1)

	END

	UPDATE [Feeds]
	   SET [Feed_Name] = COALESCE(@Feed_Name, [Feed_Name]),
	       [Feed_Description] = NULLIF(COALESCE(@Feed_Description, [Feed_Description]), ''),
		   [Active_Indicator] = COALESCE(@Active_Indicator, [Active_Indicator]),
		   [Cache_Connectors_Indicator] = COALESCE(@Cache_Connectors_Indicator, [Cache_Connectors_Indicator]),
		   [FeedType_Name] = COALESCE(@FeedType_Name, [FeedType_Name]),
		   [DropPath_Text] = NULLIF(COALESCE(@DropPath_Text, [DropPath_Text]), ''),
		   [FeedPathOverride_Text] = NULLIF(COALESCE(@FeedPathOverride_Text, [FeedPathOverride_Text]), ''),
		   [PackageStoreConfiguration_Xml] = NULLIF(COALESCE(@PackageStoreConfiguration_Xml, CAST([PackageStoreConfiguration_Xml] AS NVARCHAR(MAX))), ''),
		   [AllowUnknownLicenses_Indicator] = NULLIF(COALESCE(@AllowUnknownLicenses_Indicator2, [AllowUnknownLicenses_Indicator]), ''),
		   [FeedConfiguration_Xml] = NULLIF(COALESCE(@FeedConfiguration_Xml, CAST([FeedConfiguration_Xml] AS NVARCHAR(MAX))), ''),
		   [ReplicationConfiguration_Xml] = NULLIF(COALESCE(@ReplicationConfiguration_Xml, CAST([ReplicationConfiguration_Xml] AS NVARCHAR(MAX))), '')
	 WHERE [Feed_Id] = @Feed_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Feeds_SetFeedProperty] TO [ProGetUser_Role]
GO