EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'NuGetPackagesV2_DeletePackage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes a package from a feed.'
GO

IF OBJECT_ID('[NuGetPackagesV2_DeletePackage]') IS NOT NULL DROP PROCEDURE [NuGetPackagesV2_DeletePackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [NuGetPackagesV2_DeletePackage]
(
	@Feed_Id INT,
	@Package_Id VARCHAR(255),
	@Version_Text VARCHAR(255),
	@LatestVersion_Text VARCHAR(255),
	@LatestStableVersion_Text VARCHAR(255)
)
AS
BEGIN

	SET NOCOUNT ON

	BEGIN TRY
		BEGIN TRANSACTION

		IF @Version_Text IS NULL
		BEGIN

			DELETE FROM [NuGetPackageSymbolsV2]
			 WHERE [Feed_Id] = @Feed_Id

			DELETE FROM [NuGetPackagesV2]
			 WHERE [Feed_Id] = @Feed_Id

		END ELSE BEGIN

			DECLARE @NuGetPackageV2_Id INT
			SET @NuGetPackageV2_Id = (SELECT [NuGetPackageV2_Id]
			                            FROM [NuGetPackagesV2]
										WITH (TABLOCKX)
									   WHERE [Feed_Id] = @Feed_Id
									     AND [Package_Id] = @Package_Id)

			DELETE FROM [NuGetPackageSymbolsV2]
			 WHERE [NuGetPackageV2_Id] = @NuGetPackageV2_Id
			   AND [Package_Version_Text] = @Version_Text

			DELETE FROM [NuGetPackageVersionsV2]
			 WHERE [NuGetPackageV2_Id] = @NuGetPackageV2_Id
			   AND [Version_Text] = @Version_Text

			EXEC [Events_RaiseEvent] 'PKGDEL', @Feed_Id, 'Package_Name', @Package_Id, 'Package_Version', @Version_Text


			IF NOT EXISTS(SELECT * FROM [NuGetPackageVersionsV2] WHERE [NuGetPackageV2_Id] = @NuGetPackageV2_Id)

				DELETE FROM [NuGetPackagesV2]
				 WHERE [NuGetPackageV2_Id] = @NuGetPackageV2_Id

			ELSE IF @LatestVersion_Text IS NOT NULL OR @LatestStableVersion_Text IS NOT NULL

				UPDATE [NuGetPackagesV2]
				   SET [LatestVersion_Text] = @LatestVersion_Text,
				       [LatestStableVersion_Text] = @LatestStableVersion_Text
				 WHERE [NuGetPackageV2_Id] = @NuGetPackageV2_Id

		END

		COMMIT
	END TRY BEGIN CATCH
		IF XACT_STATE()<>0 ROLLBACK
		EXEC [HandleError]
	END CATCH

END
GO

GRANT EXECUTE ON [NuGetPackagesV2_DeletePackage] TO [ProGetUser_Role]
GO
